@@ -254,11 +254,9 @@ function m3SetWysiwygEditor(id, height, toolbarVisible, barType)
 		
 	if (M3_WYSIWYG_EDITOR == 'ckeditor'){
 		var config = {};
-//		if (M3_USE_GOOGLEMAPS){
-			config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
-//		} else {
-//			config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig_intranet.js';
-//		}
+		config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
+	//	if (M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES) config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES;
+		if (typeof(M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES;
 		if (height) config['height'] = height;
 		if (toolbarVisible != null && !toolbarVisible) config['toolbarStartupExpanded'] = false;
 		if (barType){
