@@ -29,9 +29,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 	private $menuData = array();			// Joomla用のメニューデータ
 	private $menuTree = array();			// Joomla用のメニュー階層データ
 	private $renderType;		// 描画出力タイプ
+	private $showLogin;			// ログインフィールドを表示するかどうか
+	private $loginFailed;		// ログイン失敗かどうか
 	const DEFAULT_CONFIG_ID = 0;
 	const MAX_MENU_TREE_LEVEL = 5;			// メニュー階層最大数
 	const DEFAULT_BOOTSTRAP_CSS_FILE = '/bootstrap.css';		// CSSファイル
+	const LOGIN_FAIL_MARK = '<i class="glyphicon glyphicon-remove-circle error" title="ログイン失敗" rel="tooltip" data-placement="auto"></i> ';		// ログイン失敗表示
+	const LOGIN_FAIL_MESSAGE = '<p class="message error">ログインに失敗しました</p>';
 	
 	/**
 	 * コンストラクタ
@@ -145,8 +149,43 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$useVerticalMenu 	= $targetObj->useVerticalMenu;		// 縦型メニューデザインを使用するかどうか
 		$showSitename	= isset($targetObj->showSitename) ? $targetObj->showSitename : 1;		// サイト名を表示するかどうか
 		$showSearch		= isset($targetObj->showSearch) ? $targetObj->showSearch : 0;			// 検索フィールドを表示するかどうか
+		$this->showLogin	= isset($targetObj->showLogin) ? $targetObj->showLogin : 0;			// ログインを表示するかどうか
 		$anotherColor	= isset($targetObj->anotherColor) ? $targetObj->anotherColor : 0;		// 色を変更するかどうか
 		
+		$act = $request->trimValueOf('act');
+		if ($act == 'nav_login'){			// ログインのとき
+			// アカウント、パスワード取得
+			$account = $request->trimValueOf('account');
+			$password = $request->trimValueOf('password');
+			$autoLogin = ($request->trimValueOf('autologin') == 'on') ? 1 : 0;		// 自動ログインを使用するかどうか
+			
+			// ユーザ認証
+			if ($this->gAccess->userLoginByAccount($account, $password)){
+				$userId = $this->gEnv->getCurrentUserId();
+				
+				// ### 自動ログインの処理 ###
+				// 自動ログインしないに設定した場合は自動ログイン情報を削除
+				$this->gAccess->userAutoLogin($userId, $autoLogin);
+				
+				// 画面を全体を再表示する
+				$this->gPage->redirect($this->gEnv->getCurrentRequestUri());
+				return;
+			} else {		// ログイン失敗の場合
+				// ログイン状態を削除
+				$this->gAccess->userLogout();
+				
+				$this->loginFailed = true;		// ログイン失敗かどうか
+//				$this->tmpl->setAttribute('login_status', 'visibility', 'visible');		// ログイン状況
+//				$this->tmpl->addVar("login_status", "message", 'ログインに失敗しました');
+			}
+		} else if ($act == 'nav_logout'){			// ログアウトのとき
+			$this->gAccess->userLogout();
+			
+			// 画面を全体を再表示する
+			$this->gPage->redirect($this->gEnv->getCurrentRequestUri());
+			return;
+		}
+		
 		// 縦型メニューデザイン使用の場合はJoomla用パラメータを設定
 		if (!empty($useVerticalMenu)) $this->gEnv->setCurrentWidgetJoomlaParam(array('moduleclass_sfx' => 'art-vmenu'));
 
@@ -177,6 +216,26 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				// 検索フィールド表示制御
 				if ($showSearch) $this->tmpl->setAttribute('show_search', 'visibility', 'visible');
 
+				// ログインフィールド表示制御
+				if ($this->showLogin){
+					// ログイン状態を取得
+					$userName = $this->gEnv->getCurrentUserName();
+					if (empty($userName)){		// ユーザがログインしていないとき
+						$this->tmpl->setAttribute('show_login', 'visibility', 'visible');
+						
+						// ログイン失敗の表示
+						if ($this->loginFailed){
+							$this->tmpl->addVar("show_login", "login_status", self::LOGIN_FAIL_MARK);		// アイコン
+							$this->tmpl->addVar("show_login", "message", self::LOGIN_FAIL_MESSAGE);		// メッセージ
+						}
+					} else {
+						$this->tmpl->setAttribute('show_logout', 'visibility', 'visible');
+						$this->tmpl->addVar("show_logout", "account", $this->convertToDispString($userName));
+					}
+					// ログイン用スクリプト追加
+					$this->tmpl->setAttribute('show_login_script', 'visibility', 'visible');
+				}
+				
 				// 追加クラス
 				// メニュー属性を取得
 				if (!empty($menuAttr['bootstyle'])) $navbarOptionClass[] = $menuAttr['bootstyle'];
@@ -208,6 +267,24 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 	{
 		return $this->cssFilePath;
 	}
+	/**
+	 * JavascriptライブラリをHTMLヘッダ部に設定
+	 *
+	 * JavascriptライブラリをHTMLのheadタグ内に追加出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。
+	 * @return string,array 				Javascriptライブラリ。出力しない場合は空文字列を設定。
+	 */
+	function _addScriptLibToHead($request, &$param)
+	{
+		if ($this->showLogin){			// ログインフィールドを表示する場合
+			return array(ScriptLibInfo::LIB_MD5, ScriptLibInfo::LIB_JQUERY_COOKIE);
+		} else {
+			return '';
+		}
+	}
 	/**
 	 * メニューツリー作成
 	 *
