@@ -35,7 +35,7 @@ $HELP['menu_id']['body'] = '自動的に振られるメニュー設定IDです
 $HELP['menu_limit_user']['title'] = 'ユーザ制限';
 $HELP['menu_limit_user']['body'] = 'メニューの表示をログインしたユーザに限定するかどうかを設定します。';
 $HELP['menu_design']['title'] = 'デザイン';
-$HELP['menu_design']['body'] = '●縦型メニュー<br />Artisteer 2.4から使用可能な「縦型メニュー」のデザインを使用するかどうかを設定します。';
+$HELP['menu_design']['body'] = '●階層化あり<br />メニュー定義を単階層あるいは多階層で定義するかを設定します。<br />●縦型メニュー<br />Artisteer型、Bootstrap型テンプレートの「縦型メニュー」のデザインを使用するかどうかを設定します。';
 $HELP['menu_def']['title'] = 'メニュー定義';
 $HELP['menu_def']['body'] = 'メニュー項目で使用するメニュー定義を選択します。定義データはシステムで共通です。<br />単階層でメニューを定義するか、多階層でメニューを定義するかを選択します。<br />メニューIDは管理機能の「システムマスター管理/メンテナンス/マスター管理/メニューID」で管理します。';
 $HELP['menu_ref']['title'] = '使用';
